==> zio-aws-codeartifact_2.13-5.17.153.2-sources.jar: zio/aws/codeartifact/model/UpdatePackageVersionsStatusResponse.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codeartifact.model.primitives.PackageVersion
import scala.jdk.CollectionConverters._
final case class UpdatePackageVersionsStatusResponse(
    successfulVersions: Option[Map[
      PackageVersion,
      zio.aws.codeartifact.model.SuccessfulPackageVersionInfo
    ]] = None,
    failedVersions: Option[
      Map[PackageVersion, zio.aws.codeartifact.model.PackageVersionError]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.UpdatePackageVersionsStatusResponse = {
    import UpdatePackageVersionsStatusResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.UpdatePackageVersionsStatusResponse
      .builder()
      .optionallyWith(
        successfulVersions.map(value =>
          value
            .map({ case (key, value) =>
              (PackageVersion.unwrap(key): java.lang.String) -> value
                .buildAwsValue()
            })
            .asJava
        )
      )(_.successfulVersions)
      .optionallyWith(
        failedVersions.map(value =>
          value
            .map({ case (key, value) =>
              (PackageVersion.unwrap(key): java.lang.String) -> value
                .buildAwsValue()
            })
            .asJava
        )
      )(_.failedVersions)
      .build()
  }
  def asReadOnly
      : zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse.ReadOnly =
    zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse
      .wrap(buildAwsValue())
}
object UpdatePackageVersionsStatusResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.UpdatePackageVersionsStatusResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse =
      zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse(
        successfulVersions.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        failedVersions.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        )
      )
    def successfulVersions: Option[Map[
      PackageVersion,
      zio.aws.codeartifact.model.SuccessfulPackageVersionInfo.ReadOnly
    ]]
    def failedVersions: Option[Map[
      PackageVersion,
      zio.aws.codeartifact.model.PackageVersionError.ReadOnly
    ]]
    def getSuccessfulVersions: ZIO[Any, AwsError, Map[
      PackageVersion,
      zio.aws.codeartifact.model.SuccessfulPackageVersionInfo.ReadOnly
    ]] = AwsError.unwrapOptionField("successfulVersions", successfulVersions)
    def getFailedVersions: ZIO[Any, AwsError, Map[
      PackageVersion,
      zio.aws.codeartifact.model.PackageVersionError.ReadOnly
    ]] = AwsError.unwrapOptionField("failedVersions", failedVersions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.UpdatePackageVersionsStatusResponse
  ) extends zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse.ReadOnly {
    override val successfulVersions: Option[Map[
      PackageVersion,
      zio.aws.codeartifact.model.SuccessfulPackageVersionInfo.ReadOnly
    ]] = scala
      .Option(impl.successfulVersions())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.codeartifact.model.primitives.PackageVersion(
              key
            ) -> zio.aws.codeartifact.model.SuccessfulPackageVersionInfo
              .wrap(value)
          })
          .toMap
      )
    override val failedVersions: Option[Map[
      PackageVersion,
      zio.aws.codeartifact.model.PackageVersionError.ReadOnly
    ]] = scala
      .Option(impl.failedVersions())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.codeartifact.model.primitives.PackageVersion(
              key
            ) -> zio.aws.codeartifact.model.PackageVersionError.wrap(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.UpdatePackageVersionsStatusResponse
  ): zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codeartifact_2.13-5.17.201.1-sources.jar: zio/aws/codeartifact/model/UpdatePackageVersionsStatusResponse.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codeartifact.model.primitives.PackageVersion
import scala.jdk.CollectionConverters._
final case class UpdatePackageVersionsStatusResponse(
    successfulVersions: Optional[Map[
      PackageVersion,
      zio.aws.codeartifact.model.SuccessfulPackageVersionInfo
    ]] = Optional.Absent,
    failedVersions: Optional[
      Map[PackageVersion, zio.aws.codeartifact.model.PackageVersionError]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.UpdatePackageVersionsStatusResponse = {
    import UpdatePackageVersionsStatusResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.UpdatePackageVersionsStatusResponse
      .builder()
      .optionallyWith(
        successfulVersions.map(value =>
          value
            .map({ case (key, value) =>
              (PackageVersion.unwrap(key): java.lang.String) -> value
                .buildAwsValue()
            })
            .asJava
        )
      )(_.successfulVersions)
      .optionallyWith(
        failedVersions.map(value =>
          value
            .map({ case (key, value) =>
              (PackageVersion.unwrap(key): java.lang.String) -> value
                .buildAwsValue()
            })
            .asJava
        )
      )(_.failedVersions)
      .build()
  }
  def asReadOnly
      : zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse.ReadOnly =
    zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse
      .wrap(buildAwsValue())
}
object UpdatePackageVersionsStatusResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.UpdatePackageVersionsStatusResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse =
      zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse(
        successfulVersions.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        failedVersions.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        )
      )
    def successfulVersions: Optional[Map[
      PackageVersion,
      zio.aws.codeartifact.model.SuccessfulPackageVersionInfo.ReadOnly
    ]]
    def failedVersions: Optional[Map[
      PackageVersion,
      zio.aws.codeartifact.model.PackageVersionError.ReadOnly
    ]]
    def getSuccessfulVersions: ZIO[Any, AwsError, Map[
      PackageVersion,
      zio.aws.codeartifact.model.SuccessfulPackageVersionInfo.ReadOnly
    ]] = AwsError.unwrapOptionField("successfulVersions", successfulVersions)
    def getFailedVersions: ZIO[Any, AwsError, Map[
      PackageVersion,
      zio.aws.codeartifact.model.PackageVersionError.ReadOnly
    ]] = AwsError.unwrapOptionField("failedVersions", failedVersions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.UpdatePackageVersionsStatusResponse
  ) extends zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse.ReadOnly {
    override val successfulVersions: Optional[Map[
      PackageVersion,
      zio.aws.codeartifact.model.SuccessfulPackageVersionInfo.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.successfulVersions())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.codeartifact.model.primitives.PackageVersion(
              key
            ) -> zio.aws.codeartifact.model.SuccessfulPackageVersionInfo
              .wrap(value)
          })
          .toMap
      )
    override val failedVersions: Optional[Map[
      PackageVersion,
      zio.aws.codeartifact.model.PackageVersionError.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.failedVersions())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.codeartifact.model.primitives.PackageVersion(
              key
            ) -> zio.aws.codeartifact.model.PackageVersionError.wrap(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.UpdatePackageVersionsStatusResponse
  ): zio.aws.codeartifact.model.UpdatePackageVersionsStatusResponse.ReadOnly =
    new Wrapper(impl)
}
